@@ -51,7 +51,7 @@ import requests
 import time
 from threading import Thread
 
-from gnomemusic import log
+from gnomemusic import log, RateLimited
 import logging
 logger = logging.getLogger(__name__)
 
@@ -95,6 +95,9 @@ class Player(GObject.GObject):
         'thumbnail-updated': (GObject.SignalFlags.RUN_FIRST, None, (str,)),
     }
 
+    def __repr__(self):
+        return '<Player>'
+
     @log
     def __init__(self, parent_window):
         GObject.GObject.__init__(self)
@@ -238,7 +241,6 @@ class Player(GObject.GObject):
         self._sync_prev_next()
         self._sync_repeat_image()
 
-    @log
     def _on_bus_state_changed(self, bus, message):
         # Note: not all state changes are signaled through here, in particular
         # transitions between Gst.State.READY and Gst.State.NULL are never async
@@ -400,8 +402,9 @@ class Player(GObject.GObject):
 
     @log
     def _get_random_iter(self, currentTrack):
+        first_iter = self.playlist.get_iter_first()
         if not currentTrack:
-            return None
+            currentTrack = first_iter
         if hasattr(self.playlist, "iter_is_valid") and\
            not self.playlist.iter_is_valid(currentTrack):
             return None
@@ -437,8 +440,8 @@ class Player(GObject.GObject):
             if currentTrack:
                 nextTrack = self.playlist.iter_next(currentTrack)
         elif self.repeat == RepeatType.SHUFFLE:
+            nextTrack = self._get_random_iter(currentTrack)
             if currentTrack:
-                nextTrack = self._get_random_iter(currentTrack)
                 self.shuffleHistory.append(currentTrack)
 
         if nextTrack:
@@ -542,6 +545,7 @@ class Player(GObject.GObject):
         return self._get_playing()
 
     @log
+    @RateLimited(1)
     def _sync_playing(self):
         if self._get_playing():
             image = self._pauseImage
@@ -634,15 +638,16 @@ class Player(GObject.GObject):
             if nextTrack:
                 self._validate_next_track(Gtk.TreeRowReference.new(self.playlist, self.playlist.get_path(nextTrack)))
 
+    @log
     def _validate_next_track(self, track=None):
         if track is None:
             track = self._get_next_track()
 
+        self.nextTrack = track
+
         if track is None:
             return
 
-        self.nextTrack = track
-
         _iter = self.playlist.get_iter(self.nextTrack.get_path())
         status = self.playlist.get_value(_iter, self.discovery_status_field)
         nextSong = self.playlist.get_value(_iter, self.playlistField)
@@ -720,7 +725,8 @@ class Player(GObject.GObject):
             return True
 
         self.stop()
-        self.currentTrack = self.nextTrack
+        self.currentTrack = self._get_next_track()
+
         if self.currentTrack and self.currentTrack.valid():
             self.currentTrackUri = self.playlist.get_value(
                 self.playlist.get_iter(self.currentTrack.get_path()), 5).get_url()
@@ -1068,6 +1074,9 @@ class Player(GObject.GObject):
 
 class MissingCodecsDialog(Gtk.MessageDialog):
 
+    def __repr__(self):
+        return '<MissingCodecsDialog>'
+
     @log
     def __init__(self, parent_window, install_helper_name):
         Gtk.MessageDialog.__init__(self,
@@ -1082,7 +1091,7 @@ class MissingCodecsDialog(Gtk.MessageDialog):
         # %s will be replaced with the software installer's name, e.g.
         # 'Software' in case of gnome-software.
         self.find_button = self.add_button(_("_Find in %s") % install_helper_name,
-                                            Gtk.ResponseType.ACCEPT)
+                                           Gtk.ResponseType.ACCEPT)
         self.set_default_response(Gtk.ResponseType.ACCEPT)
         Gtk.StyleContext.add_class(self.find_button.get_style_context(), 'suggested-action')
 
@@ -1099,8 +1108,12 @@ class MissingCodecsDialog(Gtk.MessageDialog):
                                             "%s are required to play the file, but are not installed.",
                                             n_codecs) % text)
 
+
 class SelectionToolbar():
 
+    def __repr__(self):
+        return '<SelectionToolbar>'
+
     @log
     def __init__(self):
         self._ui = Gtk.Builder()
