@@ -59,6 +59,9 @@ class ViewContainer(Gtk.Stack):
     nowPlayingIconName = 'media-playback-start-symbolic'
     errorIconName = 'dialog-error-symbolic'
 
+    def __repr__(self):
+        return '<ViewContainer>'
+
     @log
     def __init__(self, name, title, window, view_type, use_sidebar=False, sidebar=None):
         Gtk.Stack.__init__(self,
@@ -132,10 +135,9 @@ class ViewContainer(Gtk.Stack):
 
         self._init = False
         grilo.connect('ready', self._on_grilo_ready)
+        self.selection_socket = None
         self.header_bar.connect('selection-mode-changed',
                                 self._on_selection_mode_changed)
-        self.view.connect('view-selection-changed',
-                          self._on_view_selection_changed)
 
         self._discovering_urls = {}
         grilo.connect('changes-pending', self._on_changes_pending)
@@ -256,6 +258,10 @@ class ViewContainer(Gtk.Stack):
 
 # Class for the Empty View
 class Empty(Gtk.Stack):
+
+    def __repr__(self):
+        return '<EmptyView>'
+
     @log
     def __init__(self, window, player):
         Gtk.Stack.__init__(self,
@@ -275,6 +281,10 @@ class Empty(Gtk.Stack):
 
 # Class for the Initial State
 class InitialState(Empty):
+
+    def __repr__(self):
+        return '<InitialState>'
+
     @log
     def __init__(self, window, player):
         Empty.__init__(self, window, player)
@@ -294,6 +304,10 @@ class InitialState(Empty):
 
 
 class Albums(ViewContainer):
+
+    def __repr__(self):
+        return '<Albums>'
+
     @log
     def __init__(self, window, player):
         ViewContainer.__init__(self, 'albums', _("Albums"), window, Gd.MainViewType.ICON)
@@ -385,6 +399,10 @@ class Albums(ViewContainer):
 
 
 class Songs(ViewContainer):
+
+    def __repr__(self):
+        return '<Songs>'
+
     @log
     def __init__(self, window, player):
         ViewContainer.__init__(self, 'songs', _("Songs"), window, Gd.MainViewType.LIST)
@@ -583,6 +601,10 @@ class Songs(ViewContainer):
 
 
 class Artists (ViewContainer):
+
+    def __repr__(self):
+        return '<Artists>'
+
     @log
     def __init__(self, window, player):
         ViewContainer.__init__(self, 'artists', _("Artists"),
@@ -602,19 +624,14 @@ class Artists (ViewContainer):
         )
         self.artistAlbumsStack.add_named(self._artistAlbumsWidget, "sidebar")
         self.artistAlbumsStack.set_visible_child_name("sidebar")
+        self.view.set_shadow_type(Gtk.ShadowType.IN)
+        self.view.get_style_context().add_class('side-panel')
         self.view.set_hexpand(False)
         self.view.get_generic_view().get_selection().set_mode(
             Gtk.SelectionMode.SINGLE)
         self._grid.attach(self.artistAlbumsStack, 2, 0, 2, 2)
         self._add_list_renderers()
         self.view.get_generic_view().get_style_context().remove_class('content-view')
-        if (Gtk.Settings.get_default().get_property(
-                'gtk_application_prefer_dark_theme')):
-            self.view.get_generic_view().get_style_context().\
-                add_class('artist-panel-dark')
-        else:
-            self.view.get_generic_view().get_style_context().\
-                add_class('artist-panel-white')
         self.show_all()
         self.view.hide()
 
@@ -629,7 +646,6 @@ class Artists (ViewContainer):
 
     @log
     def _populate(self, data=None):
-        selection = self.view.get_generic_view().get_selection()
         self._init = True
         self.populate()
 
@@ -688,8 +704,8 @@ class Artists (ViewContainer):
         artistAlbums = None
 
         artistAlbums = Widgets.ArtistAlbums(
-		    artist, albums, self.player,
-		    self.header_bar, self.selection_toolbar, self.window
+            artist, albums, self.player,
+            self.header_bar, self.selection_toolbar, self.window
         )
         self._artists[artist.casefold()]['widget'] = artistAlbums
         new_artistAlbumsWidget.add(artistAlbums)
@@ -787,11 +803,12 @@ class Playlist(ViewContainer):
         'playlist-songs-loaded': (GObject.SignalFlags.RUN_FIRST, None, ()),
     }
 
+    def __repr__(self):
+        return '<Playlist>'
+
     @log
     def __init__(self, window, player):
-        self.playlists_sidebar = Gd.MainView(
-            shadow_type=Gtk.ShadowType.NONE
-        )
+        self.playlists_sidebar = Gd.MainView()
 
         ViewContainer.__init__(self, 'playlists', _("Playlists"), window,
                                Gd.MainViewType.LIST, True, self.playlists_sidebar)
@@ -833,7 +850,7 @@ class Playlist(ViewContainer):
         self.playlists_sidebar.set_view_type(Gd.MainViewType.LIST)
         self.playlists_sidebar.set_model(self.playlists_model)
         self.playlists_sidebar.set_hexpand(False)
-        #self.playlists_sidebar.get_style_context().add_class('artist-panel')
+        self.playlists_sidebar.get_style_context().add_class('side-panel')
         self.playlists_sidebar.get_generic_view().get_selection().set_mode(
             Gtk.SelectionMode.SINGLE)
         self.playlists_sidebar.connect('item-activated', self._on_playlist_activated)
@@ -842,13 +859,6 @@ class Playlist(ViewContainer):
         self._grid.child_set_property(self.stack, 'height', 2)
         self._add_sidebar_renderers()
         self.playlists_sidebar.get_generic_view().get_style_context().remove_class('content-view')
-        if (Gtk.Settings.get_default().get_property(
-                'gtk_application_prefer_dark_theme')):
-            self.playlists_sidebar.get_generic_view().get_style_context().\
-                add_class("artist-panel-dark")
-        else:
-            self.playlists_sidebar.get_generic_view().get_style_context().\
-                add_class("artist-panel-white")
 
         self.iter_to_clean = None
         self.iter_to_clean_model = None
@@ -953,6 +963,9 @@ class Playlist(ViewContainer):
         pass
 
     def _on_list_widget_duration_render(self, col, cell, model, _iter, data):
+        if not model.iter_is_valid(_iter):
+            return
+
         item = model.get_value(_iter, 5)
         if item:
             seconds = item.get_duration()
@@ -964,6 +977,9 @@ class Playlist(ViewContainer):
         pass
 
     def _on_list_widget_type_render(self, coll, cell, model, _iter, data):
+        if not model.iter_is_valid(_iter):
+            return
+
         item = model.get_value(_iter, 5)
         if item:
             cell.set_property('text', item.get_string(Grl.METADATA_KEY_ALBUM) or _("Unknown Album"))
@@ -973,6 +989,9 @@ class Playlist(ViewContainer):
             cell.set_visible(False)
             return
 
+        if not model.iter_is_valid(_iter):
+            return
+
         if model.get_value(_iter, 11) == DiscoveryStatus.FAILED:
             cell.set_property('icon-name', self.errorIconName)
             cell.set_visible(True)
@@ -1051,7 +1070,7 @@ class Playlist(ViewContainer):
             playlist = self.playlists_model.get_value(_iter, 5)
             if str(playlist_id) == playlist.get_id() and self.current_playlist == playlist:
                 path = self.playlists_model.get_path(_iter)
-                self._on_playlist_activated(None, None, path)
+                GLib.idle_add(self._on_playlist_activated, None, None, path)
                 break
             _iter = self.playlists_model.iter_next(_iter)
 
@@ -1109,24 +1128,10 @@ class Playlist(ViewContainer):
 
         # if the active queue has been set by this playlist,
         # use it as model, otherwise build the liststore
-        self.model = Gtk.ListStore(
-            GObject.TYPE_STRING,
-            GObject.TYPE_STRING,
-            GObject.TYPE_STRING,
-            GObject.TYPE_STRING,
-            GdkPixbuf.Pixbuf,
-            GObject.TYPE_OBJECT,
-            GObject.TYPE_BOOLEAN,
-            GObject.TYPE_INT,
-            GObject.TYPE_STRING,
-            GObject.TYPE_BOOLEAN,
-            GObject.TYPE_BOOLEAN,
-            GObject.TYPE_INT
-        )
-        self.view.set_model(self.model)
-        GLib.idle_add(grilo.populate_playlist_songs, playlist, self._add_item)
+        self.model = self.view.get_model()
+        self.model.clear()
         self.songs_count = 0
-        self._update_songs_count()
+        GLib.idle_add(grilo.populate_playlist_songs, playlist, self._add_item)
 
         # disable delete button if current playlist is a smart playlist
         if self.current_playlist_is_protected():
@@ -1141,6 +1146,9 @@ class Playlist(ViewContainer):
     @log
     def _add_item_to_model(self, item, model):
         if not item:
+            self._update_songs_count()
+            if self.player.playlist:
+                self.player._validate_next_track()
             self.emit('playlist-songs-loaded')
             return
         self._offset += 1
@@ -1154,7 +1162,6 @@ class Playlist(ViewContainer):
             [2, 3, 5, 9],
             [title, artist, item, bool(item.get_lyrics())])
         self.songs_count += 1
-        self._update_songs_count()
 
     @log
     def _update_songs_count(self):
@@ -1285,6 +1292,10 @@ class Playlist(ViewContainer):
 
 
 class EmptySearch(ViewContainer):
+
+    def __repr__(self):
+        return '<EmptySearch>'
+
     @log
     def __init__(self, window, player):
         ViewContainer.__init__(self, 'emptysearch', None, window, Gd.MainViewType.LIST)
@@ -1314,6 +1325,9 @@ class Search(ViewContainer):
         'no-music-found': (GObject.SignalFlags.RUN_FIRST, None, ())
     }
 
+    def __repr__(self):
+        return '<Search>'
+
     @log
     def __init__(self, window, player):
         ViewContainer.__init__(self, 'search', None, window, Gd.MainViewType.LIST)
@@ -1394,6 +1408,7 @@ class Search(ViewContainer):
                 self.header_bar, self.selection_toolbar, self.window, True
             )
             self.add(self._artistAlbumsWidget)
+            self._artistAlbumsWidget.show()
 
             self.header_bar.set_state(ToolbarState.SEARCH_VIEW)
             self.header_bar.header_bar.set_title(artist)
@@ -1452,9 +1467,10 @@ class Search(ViewContainer):
 
         model, category = data
 
-        self.found_items_number = (self.model.iter_n_children(self.head_iters[0])+
-            self.model.iter_n_children(self.head_iters[1])+
-            self.model.iter_n_children(self.head_iters[2])+
+        self.found_items_number = (
+            self.model.iter_n_children(self.head_iters[0]) +
+            self.model.iter_n_children(self.head_iters[1]) +
+            self.model.iter_n_children(self.head_iters[2]) +
             self.model.iter_n_children(self.head_iters[3]))
 
         if category == 'song' and self.found_items_number == 0 and remaining == 0:
