@@ -52,6 +52,9 @@ playlist = Playlists.get_default()
 
 class Window(Gtk.ApplicationWindow):
 
+    def __repr__(self):
+        return '<Window>'
+
     @log
     def __init__(self, app):
         Gtk.ApplicationWindow.__init__(self,
@@ -69,6 +72,7 @@ class Window(Gtk.ApplicationWindow):
         self.add_action(selectNone)
         self.set_size_request(200, 100)
         self.set_icon_name('gnome-music')
+        self.notification_handler = None
 
         self.prev_view = None
         self.curr_view = None
@@ -91,20 +95,6 @@ class Window(Gtk.ApplicationWindow):
         self.window_size_update_timeout = None
         self.connect("window-state-event", self._on_window_state_event)
         self.connect("configure-event", self._on_configure_event)
-
-        self.proxy = Gio.DBusProxy.new_sync(Gio.bus_get_sync(Gio.BusType.SESSION, None),
-                                            Gio.DBusProxyFlags.NONE,
-                                            None,
-                                            'org.gnome.SettingsDaemon',
-                                            '/org/gnome/SettingsDaemon/MediaKeys',
-                                            'org.gnome.SettingsDaemon.MediaKeys',
-                                            None)
-        self._grab_media_player_keys()
-        try:
-            self.proxy.connect('g-signal', self._handle_media_keys)
-        except GLib.GError:
-            # We cannot grab media keys if no settings daemon is running
-            pass
         grilo.connect('changes-pending', self._on_changes_pending)
 
     @log
@@ -153,19 +143,27 @@ class Window(Gtk.ApplicationWindow):
 
     @log
     def _grab_media_player_keys(self):
-        try:
-            self.proxy.call_sync('GrabMediaPlayerKeys',
-                                 GLib.Variant('(su)', ('Music', 0)),
-                                 Gio.DBusCallFlags.NONE,
-                                 -1,
-                                 None)
-        except GLib.GError:
-            # We cannot grab media keys if no settings daemon is running
-            pass
+        self.proxy = Gio.DBusProxy.new_sync(Gio.bus_get_sync(Gio.BusType.SESSION, None),
+                                            Gio.DBusProxyFlags.NONE,
+                                            None,
+                                            'org.gnome.SettingsDaemon',
+                                            '/org/gnome/SettingsDaemon/MediaKeys',
+                                            'org.gnome.SettingsDaemon.MediaKeys',
+                                            None)
+        self.proxy.call_sync('GrabMediaPlayerKeys',
+                             GLib.Variant('(su)', ('Music', 0)),
+                             Gio.DBusCallFlags.NONE,
+                             -1,
+                             None)
+        self.proxy.connect('g-signal', self._handle_media_keys)
 
     @log
     def _windows_focus_cb(self, window, event):
-        self._grab_media_player_keys()
+        try:
+            self._grab_media_player_keys()
+        except GLib.GError:
+            # We cannot grab media keys if no settings daemon is running
+            pass
 
     @log
     def _handle_media_keys(self, proxy, sender, signal, parameters):
@@ -205,6 +203,7 @@ class Window(Gtk.ApplicationWindow):
         count = 0
         cursor = None
 
+        Query()
         if Query.music_folder and Query.download_folder:
             try:
                 cursor = tracker.query(Query.all_songs_count(), None)
@@ -333,8 +332,11 @@ class Window(Gtk.ApplicationWindow):
         label = Gtk.Label.new(_("Loading"))
         grid.add(label)
         self.notification.add(grid)
-        self.notification.show_all()
-        GLib.timeout_add(1000, self._overlay.add_overlay, self.notification)
+        self._overlay.add_overlay(self.notification)
+        if self.notification_handler:
+            GLib.Source.remove(self.notification_handler)
+            self.notification_handler = None
+        self.notification_handler = GLib.timeout_add(1000, self.notification.show_all)
 
     @log
     def _init_playlist_removal_notification(self):
